summaryrefslogtreecommitdiff
path: root/include/trace/events
diff options
context:
space:
mode:
authorMike Snitzer <snitzer@redhat.com>2010-11-16 12:52:38 +0100
committerJens Axboe <jaxboe@fusionio.com>2010-11-16 12:53:39 +0100
commitd07335e51df0c6dec202d315fc4f1f7e100eec4e (patch)
treedb6ac1db8d87738b9e44497e082d490c14413f5d /include/trace/events
parent5fbf85639287b6ea287f4f5e5e7e36608f0f60bd (diff)
block: Rename "block_remap" tracepoint to "block_bio_remap" to clarify the event.
Signed-off-by: Kiyoshi Ueda <k-ueda@ct.jp.nec.com> Signed-off-by: Jun'ichi Nomura <j-nomura@ce.jp.nec.com> Signed-off-by: Mike Snitzer <snitzer@redhat.com> Signed-off-by: Jens Axboe <jaxboe@fusionio.com>
Diffstat (limited to 'include/trace/events')
-rw-r--r--include/trace/events/block.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/include/trace/events/block.h b/include/trace/events/block.h
index d8ce278515c3..b56c65dc105d 100644
--- a/include/trace/events/block.h
+++ b/include/trace/events/block.h
@@ -486,16 +486,16 @@ TRACE_EVENT(block_split,
);
/**
* block_remap - map request for a partition to the raw device
* @q: queue holding the operation
* @bio: revised operation
* @dev: device for the operation
* @from: original sector for the operation
*
- * An operation for a partition on a block device has been mapped to the
+ * An operation for a logical device has been mapped to the
* raw block device.
*/
-TRACE_EVENT(block_remap,
+TRACE_EVENT(block_bio_remap,
TP_PROTO(struct request_queue *q, struct bio *bio, dev_t dev,
sector_t from),
@@ -486,16 +486,16 @@ TRACE_EVENT(block_split,
);
/**
- * block_remap - map request for a partition to the raw device
+ * block_bio_remap - map request for a logical device to the raw device
* @q: queue holding the operation
* @bio: revised operation